# CINCIA's LCA + RothC #####
## David Lefebvre - 22.07.2020 =====


# Libraries ##################################################################
library(SoilR)  ## RothC
library(SPEI)   ## Thornthwaite potential evapotranspiration
library(deSolve)
library(lattice)
library(tidyverse)
library(tidyr)
library(readr)
library(EnvStats)
library(patchwork)

# DATA ##################################################################
N <- 10000
SeedNumb <- 1.111  # Number of seedling planted in thousands per hectare (CINCIA:1.111; 4.601 as of 2020 ; Ecosia: 2.368 in 2021....)
YieldBC <- 0.3  #Yield w/w biomass/biochar
Biomass <- 1.111/YieldBC # biochar  quantity per hectare (in t ) divided by the yield biomass in T
DistOffIIAPTruck <- 200 #21 km road from Office to IIAP
DistIIapLabTruck <- 36 #36 km road from IIAP to Laberinto
DistMazLabTruck <- 128 # 128 km road distance from mazuko to laberinto 
DistLabPaoBoat <- 9 # 9 km river distance ==> Not Used Here
GasConsumBoat <- 4.25/1.111*SeedNumb # 5 liters (density of 0.85 kg/L) of gasoline are necessary for boat transport of plants for 1ha
TotWeightPlants <- 0.121/1.111*SeedNumb # 121 kg for 1100 seedlings (1ha) in t
BCQuant <- Biomass*YieldBC # biochar quqntity per hectare (in t )

#Emissions Factors
EfCH4 <- 28
EfNox <- -11
EfN2O <- 265
#For EfCO
smEfCO <- rep(NA, N) #Create an empty vector of lenght "N". NA is "missing data"
head(smEfCO) # Filled with "missing data" 
for(i in 1:N){
  sim_data <- runif(n = 10, min = 2 , max = 3.3 ) #simulate the data from that distribution
  smEfCO[i] <- mean(sim_data) # calculate the means
  rm(sim_data) #While this gets over-written each iteration of the loop,
}
hist(smEfCO)

EFGasoline <- 0.88 # kgCO2/kg   Low Sulfur Petrol Simapro
EFLoader <- 3.2 #kg co2 eq per l of diesel in a front loader
EFElec <- 0.392 # kgCO2eq per kWh
EfHL <- 0.41*0.3  # kgCO2e per hour of work for a manual worker (Rugani et al., 2012)

#Emission Factor Transportation ==> Add 20% due to rough terrain.
EFTr <- c(0.219,0.2628) # Emission Factor Range for Truck CO2eq emission [kgCO2/tkm] - Original=0.219
smEFTr <- rep(NA, N) #Create an empty vector of length "N". NA is "missing data"
head(smEFTr) # Fill with "missing data"

for(i in 1:N){
  sim_data <- runif(n = 2, min = min(EFTr) , max = max(EFTr) ) #simulate the data from that distribution
  smEFTr[i] <- mean(sim_data) # calculate the means
  rm(sim_data) #While this gets over-written each iteration of the loop,
}

# BIOCHAR PLANT ##################################################################
## Biomass Loading ====
#Front Loader consumption
LoadOp <- c(0.180,0.195) #front loader consumption (l diesel/t of Material) min: 0.180, max:0.195

smLoadOp <- rep(NA, N) #Create an empty vector of length "N". NA is "missing data"
head(smLoadOp) # Fill with "missing data"

for(i in 1:N){
  sim_data <- runif(n = 2, min = min(LoadOp) , max = max(LoadOp) ) #simulate the data from that distribution
  smLoadOp[i] <- mean(sim_data) # calculate the means
  rm(sim_data) #While this gets over-written each iteration of the loop,
}

EmissionLoad <- (((smLoadOp)*Biomass)*EFLoader) # kg CO2 / t of biochar applied


#### Biomass Transportation
BiomTransDist <- c(15,20,25) #Road distance between biomass and biochar plant [km]

smBiomTransDist <- rep(NA, N) #Create an empty vector of length "N". NA is "missing data"
head(smBiomTransDist) # Fill with "missing data"

for(i in 1:N){
  sim_data <- runif(n = 3, min = min(BiomTransDist) , max = max(BiomTransDist) )
  smBiomTransDist[i] <- mean(sim_data) # calculate the means
  rm(sim_data) #While this gets over-written each iteration of the loop,
}

EmissionBiomTrans <- (smBiomTransDist*Biomass*smEFTr) #kgco2eq per t of biochar

hist(EmissionBiomTrans)

#### Avoided Landfill emissions
EFHusk <- 0.08530905 #Simapro Waste wood, untreated {GLO}| treatment of waste wood, untreated, open dump, very wet infiltration class (1000mm) | Cut-off, U (of project Ecoinvent 3 - allocation, cut-off by classification - unit) kgCO2eq kg-1 of husks
EmissionLandfill <- EFHusk*(Biomass*1000)
EFHusk*(Biomass*1000)
TOTEmLanfillAvoid <- EmissionLandfill  #kgCO2eq /ha

#### Biochar Production
#Emission Factors
# Emissions during biochar production [kg/TBC] I consider a gamma distibution (like lognormal but less positively skewed and less tail heavy)
#FOR CH4
alpha<- 30^2/60^2
theta <-60^2/30
smBCCH4 <- rep(NA, N) #Create an empty vector of lenght "N". NA is "missing data"
head(smBCCH4) # Filled with "missing data" 
for(i in 1:N){
  sim_data <- rgamma(n = 10, shape = alpha, scale = theta) #simulate the data from that distribution
  smBCCH4[i] <- mean(sim_data) # calculate the means
  rm(sim_data) #While this gets over-written each iteration of the loop,
}
mean(smBCCH4)

hist(smBCCH4)
#FOR NOX
alpha<- 0.4^2/0.3^2
theta <-0.3^2/0.4
smBCNOx <- rep(NA, N) #Create an empty vector of lenght "N". NA is "missing data"
head(smBCNOx) # Filled with "missing data" 
for(i in 1:N){
  sim_data <- rgamma(n = 10, shape = alpha, scale = theta) #simulate the data from that distribution
  smBCNOx[i] <- mean(sim_data) # calculate the means
  rm(sim_data) #While this gets over-written each iteration of the loop,
}
mean(smBCNOx)
hist(smBCNOx)

#FOR CO
alpha<- 54^2/35^2
theta <-35^2/54
smBCCO <- rep(NA, N) #Create an empty vector of lenght "N". NA is "missing data"
head(smBCCO) # Filled with "missing data" 
for(i in 1:N){
  sim_data <- rgamma(n = 10, shape = alpha, scale = theta) #simulate the data from that distribution
  smBCCO[i] <- mean(sim_data) # calculate the means
  rm(sim_data) #While this gets over-written each iteration of the loop,
}
mean(smBCCO)
hist(smBCCO)

#####TOTALEMISSIONS during BC production
EmissionPyro <- (smBCCO*smEfCO)+(smBCNOx*EfNox)+(smBCCH4*EfCH4)  ## in kg/tBC
mean(EmissionPyro)
plot(EmissionPyro)
hist(EmissionPyro)
TOTEmPyro <- EmissionPyro*Biomass*YieldBC
hist(TOTEmPyro)

#### Biochar transport
#transport from IIAP To Laberinto
EmTransRoadBC <- (DistIIapLabTruck*Biomass*YieldBC)*smEFTr #kgCO2/ha
EmTransRivBC <- ((GasConsumBoat * EFGasoline)*2)*Biomass*YieldBC

#####TOTAL EMISSION Biochar plant-------
TOTEmBCPlant <-  EmissionBiomTrans + EmissionLoad*2 + TOTEmPyro +EmTransRivBC+ EmTransRoadBC # kgCO2eq / ha 

mean(EmissionBiomTrans + EmissionLoad*2 + TOTEmPyro +EmTransRivBC+ EmTransRoadBC)



hist(TOTEmBCPlant)

### NURSERY ----
####Amendments
#Trasnport Amendment
AmendmentTransDist <- c(100,200) #Road distance between biomass and biochar plant [km]

smAmendmentTransDist <- rep(NA, N) #Create an empty vector of length "N". NA is "missing data"
head(smAmendmentTransDist) # Fill with "missing data"

for(i in 1:N){
  sim_data <- runif(n = 1, min = min(AmendmentTransDist) , max = max(AmendmentTransDist) )
  smAmendmentTransDist[i] <- mean(sim_data) # calculate the means
  rm(sim_data) #While this gets over-written each iteration of the loop,
}
mean(smAmendmentTransDist)

#Semi-Carbonized Rice husk
massRH <- 100*SeedNumb # kg rice husk for 1100 plants
RiceHuskBC <-(EmissionPyro/1000 * massRH) # kgCO2eq per kgBC rice husk

#Decomposed Saw dust 
massSD <- 75*SeedNumb #mass saw dust [kg]
EFSD <- 0.0293  # Emission factor saw dust [kgCO2eq/kg saw dust]

#Poultry Manure 
massPM <- 150*SeedNumb #mass Poultry Manure [kg]
EFPM <- 0.19643292 # Emission factor Poultry Manure [kgCO2eq/kg Poultry Manure]

#Cow Manure 
massCM <- 100*SeedNumb #mass Cow Manure [kg]
EFCM <- 0.038796506 # Emission factor Cow Manure [kgCO2eq/kg Poultry Manure]

#Organic Soil (compost)
massOS <- 100*SeedNumb #mass organic soil [kg]
EFOS <- 0.211 # Emission factor organic soil [kgCO2eq/kg organic soil]

#Fertilizer NPK 
massNPK <- 6* SeedNumb #mass NPK [kg]
EFNPK <- 0.903 #Emission factor NPK [kgCO2eq/kg NPK]

#Diammonium Phosphate
massAmPh <- 3*1.1 #mass Diammonium Phosphate [kg]
EFAmPh <- 2.87 # Emission factor Diammonium Phosphate [kgCO2eq/ kg Diammonium Phosphate]

#Potassium Chloride
massPoCh <- 0.3*SeedNumb #mass potassium chloraide
EFPoCh <- 0.568 # Emission Factor Potassium Chloride [kgCO2eq/kg Potass Chlo]

#Fungicide - Cupravit
massCup <- 0.2*SeedNumb #Mass Cupravit [kg]
EFCup <- 11 # Emission Factor Cupravit [kgCO2eq/kg Cupravit]

#Fungicide - Benzomil
massBenz <- 0.3*SeedNumb #Mass Benzomil [kg]
EFBenz <- 8.43 # Emission Factor Benzomil [kgCO2eq/kg Benzomil]


TOTEmAmNurs <-smEFTr*smAmendmentTransDist*((massSD+massRH+massOS+massNPK+massPoCh+massCup+massCM+massPM+massBenz)/1000)+(RiceHuskBC+ massSD*EFSD+ massOS*EFOS+ massNPK*EFNPK+ massPoCh*EFPoCh+ massCup*EFCup + massCM*EFCM + massPM*EFPM + massBenz*EFBenz) # Emissions amendment Nursery for 1100 plants (1 ha) in kgCO2eq 
mean(TOTEmAmNurs)

####Electricity
ElecNurs <- 102*SeedNumb/1.1 #kWh for 5 months of plant growth
TOTEmElecNurs <- ElecNurs*EFElec # kgCO2 per ha 

####Transport 
#transport from Mazuko To Paolita
EmTransRoadNurs <- (DistMazLabTruck*TotWeightPlants)*smEFTr #kgCO2/ha
EmTransRivNurs <- (GasConsumBoat * EFGasoline)*2*(TotWeightPlants/0.121) #time 2 because two boat needed
TOTTransNurs <- EmTransRivNurs+EmTransRoadNurs

#####TOTAL EMISSION Nursery-------
TOTEmNursery <- TOTEmAmNurs + TOTEmElecNurs + TOTTransNurs

mean(TOTTransNurs)
mean(TOTTransNurs)
sd(TOTTransNurs)

### FIELD WORKS ----
#Transport: Team of 8 people 75 kg + 10 kg of food and gears average, 3 round trip
EmTransRoadFW <- ((DistIIapLabTruck+DistOffIIAPTruck)*(0.085*8))*smEFTr #kgCO2/ha
EmTransRivFW <- (GasConsumBoat * EFGasoline)*2
TOTTransFW <- (EmTransRivFW + EmTransRoadFW) * 3  #kgCO2eq/ ha 

#100 kh/ha of NPK
massNPKFW <- (100/1.1)*SeedNumb #kg NPK at field
TOTNPKFW <- (massNPKFW * EFNPK)+((DistIIapLabTruck+DistOffIIAPTruck)*massNPKFW/1000*smEFTr)

#Account for manpower in LCA 
EmHLFW <- ((EfHL*8*3*8)/1.1)*SeedNumb # 8 persons for 8 hours for 3 days /ha 


#### Nitrous Oxide Emissions----
TotN <- (massPM*0.046 + massCM*0.006 + massNPK*0.15 + massNPKFW*0.2 + massAmPh*0.18) #30.33 for 1100 plants/ha # kg N per ha
TotSyntN <- (massNPK*0.15 + massNPKFW*0.2 + massAmPh*0.18) #22.08 # kg of N from sythetic origin per ha (see overview reforestation Word)
TotOrgN <- (massPM*0.046 + massCM*0.006) #8.. # kg of N from Organic origin per ha 

##Emission Factor Direct Emissions N2O 
NEf1 <- c(0.003,0.01,0.03) #Emission Factor Direct Emission of N2O-N (IPCC 2006 tier 1) 

smNEf1 <- rep(NA, N) #Create an empty vector of length "N". NA is "missing data"
head(smNEf1) # Fill with "missing data"

for(i in 1:N){
  sim_data <- rtri(n = 1, min = min(NEf1) , max = max(NEf1), mode=0.01 ) #simulate the data from that distribution
  smNEf1[i] <- mean(sim_data) # calculate the means
  rm(sim_data) #While this gets over-written each iteration of the loop,
}
smNEf1

DirectN2O <- TotN*smNEf1*(44/28)

###INDIRECT N2O Emissions
##Emission Factor InDirect Emissions N2O Volatilisation
NEf4 <- c(0.002,0.01,0.05) #Emission Factor indirect Emission of N2O-N (IPCC 2006 tier 1) 

smNEf4 <- rep(NA, N) #Create an empty vector of length "N". NA is "missing data"
head(smNEf4) # Fill with "missing data"

for(i in 1:N){
  sim_data <- rtri(n = 1, min = min(NEf4) , max = max(NEf4), mode=0.01 ) #simulate the data from that distribution
  smNEf4[i] <- mean(sim_data) # calculate the means
  rm(sim_data) #While this gets over-written each iteration of the loop,
}
smNEf4

##Emission Factor InDirect Emissions N2O Leaching
NEf5 <- c(0.0005,0.0075,0.025) #Emission Factor indirect Emission of N2O-N (IPCC 2006 tier 1) 

smNEf5 <- rep(NA, N) #Create an empty vector of length "N". NA is "missing data"
head(smNEf5) # Fill with "missing data"

for(i in 1:N){
  sim_data <- rtri(n = 1, min = min(NEf5) , max = max(NEf5), mode=0.0075 ) #simulate the data from that distribution
  smNEf5[i] <- mean(sim_data) # calculate the means
  rm(sim_data) #While this gets over-written each iteration of the loop,
}
smNEf5

##Fraction Gasification volatilisation Synth Fert
FracGASF <- c(0.03,0.1,0.3) #Fraction Gasification volatilisation Synth Fert N2O-N (IPCC 2006 tier 1) 

smFracGASF <- rep(NA, N) #Create an empty vector of length "N". NA is "missing data"
head(smFracGASF) # Fill with "missing data"

for(i in 1:N){
  sim_data <- rtri(n = 1, min = min(FracGASF) , max = max(FracGASF), mode=0.1 ) #simulate the data from that distribution
  smFracGASF[i] <- mean(sim_data) # calculate the means
  rm(sim_data) #While this gets over-written each iteration of the loop,
}
smFracGASF

##Fraction Gasification volatilisation Org Fert
FracGASM <- c(0.05,0.2,0.5) #Fraction Gasification volatilisation Synth Fert N2O-N (IPCC 2006 tier 1) 

smFracGASM <- rep(NA, N) #Create an empty vector of length "N". NA is "missing data"
head(smFracGASM) # Fill with "missing data"

for(i in 1:N){
  sim_data <- rtri(n = 1, min = min(FracGASM) , max = max(FracGASM), mode=0.2 ) #simulate the data from that distribution
  smFracGASM[i] <- mean(sim_data) # calculate the means
  rm(sim_data) #While this gets over-written each iteration of the loop,
}
smFracGASM

##Fraction Leaching N Fert
FracLeach <- c(0.1,0.3,0.8) #Fraction Leaching N Fert N2O-N (IPCC 2006 tier 1) 

smFracLeach <- rep(NA, N) #Create an empty vector of length "N". NA is "missing data"
head(smFracLeach) # Fill with "missing data"

for(i in 1:N){
  sim_data <- rtri(n = 1, min = min(FracLeach) , max = max(FracLeach), mode=0.3 ) #simulate the data from that distribution
  smFracLeach[i] <- mean(sim_data) # calculate the means
  rm(sim_data) #While this gets over-written each iteration of the loop,
}
smFracLeach

IndirectN2OVol <- (TotSyntN*smFracGASF+TotOrgN*smFracGASM)*smNEf4

IndirectN2OLeach <- TotN*smFracLeach*smNEf5
TotIndirectN2O <- (IndirectN2OVol+IndirectN2OLeach)*(44/28)
mean((TotIndirectN2O+DirectN2O)*EfN2O)
#####TOTAL EMISSION Field Work-------
TOTEmFW <- TOTNPKFW + TOTTransFW + (TotIndirectN2O+DirectN2O)*EfN2O + EmHLFW


#### FIELD MAINTENANCE ----
#Transport: Team of 8 people 75 kg average + 10 kg of food and gears, 3 round trip total (3,6,12 months)
EmTransRoadFM <- ((DistIIapLabTruck+DistOffIIAPTruck)*(0.085*8))*smEFTr #kgCO2/ha
EmTransRivFM <- (GasConsumBoat * EFGasoline)*2
TOTTransFM <- (EmTransRivFM + EmTransRoadFM) * 3  #kgCO2eq/ ha 

#HUman labour
EmHLFM <- ((EfHL*8*3*8)/1.1)*SeedNumb # 8 persons for 8 hours for 3 days / ha


#####TOTAL EMISSION Field Maintenance-------
TOTFM <- TOTTransFM + EmHLFM

mean(EmHLFM)
sd(EmHLFM)
#####GRAN TOTAL EMISSION -------
TOTDF <- as_tibble(cbind(-mean(TOTFM),-mean(TOTEmFW),-mean(TOTEmNursery), -mean(TOTEmBCPlant), mean(TOTEmLanfillAvoid))) %>%
  rename(Field_Work = V2, Field_Maintenance = V1, BC_Plant = V4, Nursery = V3, Landfill_Avoid = V5)

TOTDF$BC_Soil <- Biomass*YieldBC*0.876*0.97*3.66*1000 #BC t/ha * BC Carbon content * Recalictrant part * 1000 (to put in kg)

TOTDF$Total <- -sum(mean(TOTFM)+mean(TOTEmFW)+mean(TOTEmNursery)+mean(TOTEmBCPlant)-mean(TOTEmLanfillAvoid)-mean(TOTDF$BC_Soil))

TOTDFLong <- gather(TOTDF,"Field_Work", "Field_Maintenance", "BC_Plant", "Nursery", "Landfill_Avoid","BC_Soil", "Total",key = var_name, value = value)
TOTDFLong$SD <- c(sd(TOTEmFW), sd(TOTFM), sd(TOTEmBCPlant), sd(TOTEmNursery), sd(TOTEmLanfillAvoid),sd(TOTDF$BC_Soil), sd(TOTFM+TOTEmFW+TOTEmNursery+TOTEmBCPlant-TOTEmLanfillAvoid))

TOTDF


ggplot(TOTDFLong, aes(x=var_name, y=value/1000/3.667))+
  geom_bar(aes(x=var_name, y=value/1000/3.667, fill=var_name),stat = "identity")+
  geom_errorbar(aes(x=var_name, ymin=(value-SD)/1000/3.667, ymax=(value+SD)/1000/3.667), width=.2)+
  scale_x_discrete(limits=c("BC_Plant","Landfill_Avoid","BC_Soil","Nursery","Field_Work","Field_Maintenance","Total"),
                   breaks=c("BC_Plant","Landfill_Avoid","BC_Soil","Nursery","Field_Work","Field_Maintenance","Total"),
                   labels=c("Biochar plant","Avoided composting\nemissions","Biochar in soil","Nursery","Field work","Field maintenance","Total"))+
  ylab(bquote('Carbon sequestred  ('*'tonnes C'~ ha^-1*')'))+
  xlab("")+
  theme_bw()+
  theme(axis.text.x = element_text(angle = 45, hjust = 1, size = 12))+  
  theme(legend.position="none", axis.text=element_text(size=10),axis.title=element_text(size=13)) 


TOTDFLong$value/1000
TOTDFLong$SD/1000

TOTDFALLVal <- c(-mean(EmissionBiomTrans), -mean(EmissionLoad*2), -mean (TOTEmPyro), -mean( EmTransRivBC+ EmTransRoadBC), -mean(TOTEmAmNurs), -mean(TOTEmElecNurs), -mean(TOTTransNurs), -mean(TOTNPKFW  + TOTTransFW), -mean((TotIndirectN2O+DirectN2O)*EfN2O), -mean(EmHLFW), -mean(TOTTransFM), -mean(EmHLFM), mean(TOTEmLanfillAvoid), mean(Biomass*YieldBC*0.876*0.97*3.66*1000),mean(-TOTFM-TOTEmFW-TOTEmNursery-TOTEmBCPlant+TOTEmLanfillAvoid+TOTDF$BC_Soil))

TOTDFALLNames <- c("Biomass transport", "Biomass loading", "Emissions pyrolyser","Biochar transport", "Nursery amemdment production", "Nursery electricty", "Seedling transportation", "Transportation field work", "Nitrous oxide emissions", "Human labour field work", "Transportation maintenance", "Human labour maintenance", "Avoided composting emissions", "Biochar carbon in soil", "Total")

TOTDFALLGroup <- c("Biochar plant", "Biochar plant", "Biochar plant","Biochar plant", "Nursery", "Nursery", "Nursery", "Field work", "Field work", "Field work", "Field maintenance", "Field maintenance", "Avoided composting emissions", "Biochar carbon in soil", "Total")

TOTDFALLSD <- c(sd(EmissionBiomTrans), sd(EmissionLoad*2), sd (TOTEmPyro), sd( EmTransRivBC+ EmTransRoadBC), sd(TOTEmAmNurs), sd(TOTEmElecNurs), sd(TOTTransNurs), sd(TOTNPKFW  + TOTTransFW), sd((TotIndirectN2O+DirectN2O)*EfN2O), sd(EmHLFW), sd(TOTTransFM), sd(EmHLFM), sd(TOTEmLanfillAvoid), sd(Biomass*YieldBC*0.876*0.97*3.66*1000),sd(-TOTFM-TOTEmFW-TOTEmNursery-TOTEmBCPlant+TOTEmLanfillAvoid+TOTDF$BC_Soil) )
                      
TOTDFALL <- as_tibble(cbind(TOTDFALLNames,as.numeric(TOTDFALLVal/1000/3.667),as.numeric(TOTDFALLSD/1000/3.667),TOTDFALLGroup ))%>%
  rename(Process = TOTDFALLNames, Value = V2, SD = V3, Group= TOTDFALLGroup)
TOTDFALL$Value <- as.numeric(TOTDFALL$Value)
TOTDFALL$SD <- as.numeric(TOTDFALL$SD)

ggplot(TOTDFALL, aes(x=Process, y=Value, fill=Group))+
  geom_bar(aes(x=Process, y=Value),position="stack", stat = "identity")+
  geom_errorbar(data=TOTDFLong, aes(x=Process, ymin=(Value-SD), ymax=(Value+SD)), width=.2)+
  scale_x_discrete(limits=c("Biomass transport", "Biomass loading", "Emissions pyrolyser","Biochar transport", "Nursery amemdment production", "Nursery electricty", "Seedling transportation", "Transportation field work", "Nitrous oxide emissions", "Human labour field work", "Transportation maintenance", "Human labour maintenance", "Avoided composting emissions", "Biochar carbon in soil", "Total"),
                   breaks=c("Biomass transport", "Biomass loading", "Emissions pyrolyser","Biochar transport", "Nursery amemdment production", "Nursery electricty", "Seedling transportation", "Transportation field work", "Nitrous oxide emissions", "Human labour field work", "Transportation maintenance", "Human labour maintenance", "Avoided composting emissions", "Biochar carbon in soil", "Total"),
                   labels=c("Biomass transport", "Biomass loading", "Emissions pyrolyser","Biochar transport", "Nursery amemdment production", "Nursery electricty", "Seedling transportation", "Transportation field work", "Nitrous oxide emissions", "Human labour field work", "Transportation maintenance", "Human labour maintenance", "Avoided composting emissions", "Biochar carbon in soil", "Total"))+
  ylab(bquote('Carbon sequestred  ('*'tonnes C'~ ha^-1*')'))+
  xlab("")+
  theme_bw()+
  theme(axis.text.x = element_text(angle = 45, hjust = 1, size = 12))+  
  theme(legend.position="none", axis.text=element_text(size=10),axis.title=element_text(size=13)) 

ggplot(TOTDFALL, aes(x=Group, y=Value, color=Process))+
  geom_bar(aes(x=Group, y=Value),position="stack", stat = "identity", fill="white")+
  scale_x_discrete(limits=c("Biochar plant","Avoided composting emissions","Biochar carbon in soil","Nursery","Field work","Field maintenance","Total"),
                   breaks=c("Biochar plant","Avoided composting emissions","Biochar carbon in soil","Nursery","Field work","Field maintenance","Total"),
                   labels=c("Biochar plant","Avoided composting emissions","Biochar carbon in soil","Nursery","Field work","Field maintenance","Total"))+
  ylab("")+
  xlab("")+
  ylim(c(-1,2))+
  theme_minimal()+
  theme(axis.text.x = element_text(angle = 45, hjust = 1, size = 12))+  
  theme(legend.position="none", axis.text=element_text(size=10),axis.title=element_text(size=13))+
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) 



###############################################################################

### Modifying original RothC####
fW.RothCUP<- structure(
  function 
  (P,           
   E,           
   S.Thick=23,  
   pClay=23.4,  
   pE=0.75,     
   bare=FALSE   
  )
  {  
    B= ((12*1)+(0*1.8))/12 ### Modify B to be 0 month bare and 12 month covered##
    Max.TSMD=-(20+1.3*pClay-0.01*(pClay^2))*(S.Thick/23)*(1/B)
    M=P-E*pE
    Acc.TSMD=NULL
    for(i in 2:length(M)){
      Acc.TSMD[1]=ifelse(M[1] > 0, 0, M[1])
      if(Acc.TSMD[i-1]+M[i] < 0){
        Acc.TSMD[i]=Acc.TSMD[i-1]+M[i]
      }
      else(Acc.TSMD[i]=0)
      if(Acc.TSMD[i]<=Max.TSMD) {
        Acc.TSMD[i]=Max.TSMD
      }
    }
    b=ifelse(Acc.TSMD > 0.444*Max.TSMD,1,(0.2+0.8*((Max.TSMD-Acc.TSMD)/(Max.TSMD-0.444*Max.TSMD))))
    return(data.frame(Acc.TSMD,b))
  }
  ,
  ex=function(){
    P=c(74,59,62,51,52,57,34,55,58,56,75,71) 
    E=c(8,10,27,49,83,99,103,91,69,34,16,8)  
    Rothamsted=fW.RothC(P,E)
    data.frame(month.name,P,E,0.75*E,P-0.75*E,Rothamsted)  
  }        
)

#### Create a soil cover factor to be 0 month bare and 12 month covered##

SCF <- ((0.6*12)+(1*0))/12  ### The SCF is multiplied to fT and fW at the calculation of Xi 


### Meteorological Soil and other Settings - MdD (ClimWat) ----

# Input Data from Climate Station Puerto Maldonado (Data from CLIMWAT)
MetLat <- -12.63   ##Latitude of the meteorological station
Temp=data.frame(Month=1:12, Temp=c(26.3,25.9,25.62,25.5,24.45,23.25,23.1,24.25,25.8,26.3,26.65,26.35)) ## Mean Monthly Temperature [C]
Precip=data.frame(Month=1:12, Precip=c(317,317,273,149,85,51,55,66,100,153,223,285)) ## Monthly Precipitation [mm]

Evapo <- thornthwaite(Temp[,2],lat = MetLat)
Evapo

Evp=data.frame(Month=1:12, Evp=Evapo)

# Soil
#Soil organic carbon in Mg/ha ( based on the equation: 10000(m2)*0.3(topsoil depth [m])*bulkdensity*(organic carbon%/100))

#Other
years=seq(1/12,100,by=1/12)  #time = 500 years

soil.thick=20 #soil thickness (organic layer topsoil), in cm (topsoil = 30 cm in HSWD)

DRratio <- 0.25 # DPM:RPM ratio typical for tropical woodland 


### Differential Equation increased Clay ----
## Differential equation to compute the increase of clay over time 
## Initial Condition  [tonnes/ha/year]
Clay0 <- 5.13
MaxClay <- 13.6

p <- (IClay=(MaxClay-Clay0)/40) ##Setting up the parameter (constant) [3 t/ha of litter per ha increase per year]
y0 <- (I=Clay0)  ##Setting up the initial condition
times <- years ## Time serie

#Setting the dif equation to conpute incremental increase of CLAY

ClayInc <- function(t,y,p){
  I <- y
  with (as.list(p),{          ### serves at using the individual names of the parameters and not p[1], p[2] etc...
    dIdt <- 0+IClay
    return (list(dIdt))})}

Clay1 <- as.data.frame(ode(y=y0, times, ClayInc, p))  ##report of the ode function
Clay1 <- Clay1 %>%
  rename(A = "1") 
Clay1$A[Clay1$A > MaxClay] <- MaxClay

### Differential Equation increased SOC ----
## Differential equation to compute the increase of SOC
## Initial Condition  [tonnes/ha/year]
SOC0 <- 6.35
MaxSOC <- 66.63

p <- (ISOC=(MaxSOC-SOC0)/40) ##Setting up the parameter (constant) [3 t/ha of litter per ha increase per year]
y0 <- (I=SOC0)  ##Setting up the initial condition
times <- years ## Time serie

#Setting the dif equation to conpute incremental increase of IOM

SOCInc <- function(t,y,p){
  I <- y
  with (as.list(p),{          ### serves at using the individual names of the parameters and not p[1], p[2] etc...
    dIdt <- 0+ISOC
    return (list(dIdt))})}

SOC1 <- as.data.frame(ode(y=y0, times, SOCInc, p))  ##report of the ode function

SOC1 <- SOC1 %>%
  rename(A = "1") 

SOC1$A[SOC1$A > MaxSOC] <- MaxSOC

### RothC Decomposition Rate Factor ----
# The effects of climate on decomposition can be calculated now with the functions fT.RothC and fW.RothC 

fT=fT.RothC(Temp[,2]) #Temperature effects per month
fW=fW.RothCUP(P=(Precip[,2]), E=(Evp[,2]), 
              S.Thick = soil.thick, pClay = mean(Clay1$A), 
              pE = 1.0, bare = FALSE)$b #Moisture effects per month (pE is the evaporation coef, as we use Thornthwaite, it is potential evaporation and no open pan, so the coef is set to 1)
xi.frame=data.frame(years,rep(fT*fW*SCF,length.out=length(years)))
xi.frame2=data.frame(years,rep(fT*fW*SCF*1.208,length.out=length(years)))

xiave <- mean(xi.frame[1:12,2])
xiave2 <- mean(xi.frame2[1:12,2])
mean(fT)
mean(fW)
##Even though we will assume zero carbon as initial condition for all pools, 
#we still need to know the size of the inert organic matter pool (IOM) because this pool do not change over time in RothC and it is independent on the model's dynamics. 
#Falloon et al. (1998) proposed an empirical function to determine the size of this pool based on data of the total soil organic carbon stock. The function is expressed as

FallIOM <- 0.049*min(SOC1$A)^(1.139) #IOM using Falloon method




### Differential Equation increased Forest Litter ----
## Differential equation to compute the increase of Forest litter 
## Initial Condition  [tonnes/ha/year]
FL0 <- 1.203
MaxFl <- 11.4258

(MaxFl-FL0)/40  ## Soil carbon stocks recover within 40 years of forest regeneration (Jones 2019) 

p <- (IFL=(MaxFl-FL0)/40) ##Setting up the parameter (constant) [0.126 t/ha of litter per ha increase per year]
y0 <- (I=FL0)  ##Setting up the initial condition
times <- years ## Time serie

#Setting the dif equation to compute incremental increase of Forest Litter 

ForestLit <- function(t,y,p){
  I <- y
  with (as.list(p),{          ### serves at using the individual names of the parameters and not p[1], p[2] etc...
    dIdt <- IFL*I*(1-I/MaxFl)
    return (list(dIdt))})}

FL1 <- as.data.frame(ode(y=y0, times, ForestLit, p))  ##report of the ode function

plot(FL1)

FL1 <- FL1 %>%
  rename(A = "1") 

FL1$A[FL1$A > MaxFl] <- MaxFl

#### Biochar Addition ----
# Data 
BCCContent <- 0.876 
BCadd <- Biomass*YieldBC*BCCContent ## Biochar Carbon addition [tC/ha/year] 

BCinert <- BCadd*0.95     ## Share of biochar going directly to inert pool
BCdecomp <- BCadd*(1-0.95) ## Share of biochar following decomposable pool

#Differential equation
I0 <- BCinert

p <- (IBC=BCinert) ##Setting upe the parameter (constant)
y0 <- (I=I0)  ##Setting up the initial condition
times <- years ## Time serie

#Setting the dif equation to compute incremental increase of IOM

SoilCIN <- function(t,y,p){
  I <- y
  with (as.list(p),{          ### serves at using the individual names of the parameters and not p[1], p[2] etc...
    dIdt <- 0-(I*(0.0015)) ## 15% loss in 100 years
    return (list(dIdt))})}

CIN1 <- ode(y=y0, times, SoilCIN, p)  ##report of the ode function

plot(CIN1)

CIN1 <- as.tibble(CIN1)
CIN1 <- CIN1 %>%
  rename(A = "1") 

### RothC Model ----

poolSizePM <- data.frame(matrix(ncol = 6, nrow = 1))
names(poolSizePM)<-c("DPM", "RPM", "BIO", "HUM", "IOM","Total")

#To run the model, we use the function RothCModel to initialize the model and create a SoilR Model object to which we will solve to calculate C stocks for each pool as


Model1=RothCModel(t=years,C0=c(DPM=BCdecomp, RPM=0, BIO=0, HUM=0, IOM=FallIOM),
                  In=FL1, DR=DRratio, clay=mean(Clay1$A), xi=xiave) #Loads the model
Ct1=getC(Model1) #Calculates stocks for each pool per month


matplot(years, Ct1, type="l", lty=1, col=1:5,
        xlab="Time (years)", ylab="C stocks (Mg/ha)")
legend("topleft", c("DPM", "RPM", "BIO", "HUM", "IOM"),
       lty=1, col=1:5, bty="n")


poolSize1=as.numeric(tail(Ct1,1))
poolSize1 = c(poolSize1,sum(poolSize1[1:5]))
poolSize1 <- as.vector(poolSize1)
poolSizePM [1,] <- poolSize1

poolSizePM

Ct1 <- as.data.frame(Ct1)
colnames(Ct1)<- c("DPM","RPM","BIO","HUM","IOM")
Ct1$IOM <- CIN1$A+(0.049*(SOC1$A)^(1.139))  
Ct1$TOT <- Ct1$DPM+Ct1$RPM+Ct1$BIO+Ct1$HUM+Ct1$IOM
Ct1$time <- years
Ct1$IOM <- as.numeric(Ct1$IOM)
Ct1$TOT <- as.numeric(Ct1$TOT)


ggplot(data = Ct1,aes(x=time,y=TOT))+
  geom_line()+
  ylab(bquote('Soil Carbon ('*' tonnes C'~ ha^-1*')'))+
  xlab("Years after transplant")+
  theme_bw()

### Aboveground Biomass ----
AGCUpd <- 11.46979*sqrt(years)
AGCUpdSD <- 0.249397*sqrt(years)
AGCUpdTib <- as.tibble(cbind(years, AGCUpd,AGCUpdSD))
plot(AGCUpdTib)




ggplot(AGCUpdTib, aes(x=years, y= AGCUpd ))+
  geom_line()+
  geom_ribbon(aes(ymin=AGCUpd-AGCUpdSD,ymax=AGCUpd+AGCUpdSD), alpha=0.1, linetype=2)+
  ylab(bquote('Above Ground Carbon ('*' tonnes C'~ ha^-1*')'))+
  xlab("Years after transplant")+
  theme_bw()

ggplot(AGCUpdTib, aes(x=years, y= AGCUpd ))+
  geom_line()+
  geom_ribbon(aes(ymin=AGCUpd-AGCUpdSD,ymax=AGCUpd+AGCUpdSD), alpha=0.3, linetype=2)+
  geom_crossbar(aes(x=84.5-5, y=82.72, ymin=82.72-3.82, ymax=82.72+3.82), width = 6)+
  annotate(geom = "label", x = 71-5, y = 82.72-3.82-10, label = "Messinger et al. 2016", color="red", size=4)+
  geom_crossbar(aes(x=91-5, y=83.9, ymin=83.9-36, ymax=83.9+36), width = 6)+
  annotate(geom = "label", x = 91-5, y = 83.9-36-10, label = "Csillik & Asner, 2020", color="red", size=4)+
  geom_crossbar(aes(x=6.5, y=34, ymin=24, ymax=44), width = 9)+
  annotate(geom = "label", x = 6.5, y = 44+10, label = "Asner & al, 2010", color="red", size=4)+
  geom_crossbar(aes(x=78-5, y=92.5, ymin=85, ymax=100), width = 6)+
  annotate(geom = "label", x = 65-5, y = 100+15, label = "Old tertiary substrate\nAsner & al, 2010", color="red", size=4)+
  geom_crossbar(aes(x=84.2-5, y=117.5, ymin=110, ymax=125), width = 6)+
  annotate(geom = "label", x = 83-5, y = 125+7, label = "Fertile holocene alluvial surface\nAsner & al, 2010", color="red", size=4)+
  ylab(bquote('Above Ground Carbon ('*' tonnes C'~ ha^-1*')'))+
  xlab("Years after transplant")+
  theme_bw()+
  theme(text = element_text(size=rel(4)))

### BelowGround Biomass ---- 
#but I used the three different R:S from Waring 2017. In accordance with Yaffar 2020: "smaller trees have lower root:shoot ratio than larger trees"
## Differential equation to compute the increase of R:S ratio 
## Initial Condition  [tonnes/ha/year]
RS0 <- 0.293
MaxRS <- 0.657

(MaxRS-RS0)/41  ## RS is max for old forest (stqrting at 40 yrs) 

p <- (IRS=(MaxRS-RS0)/41) ##Setting up the parameter (constant) 
y0 <- (I=RS0)  ##Setting up the initial condition
times <- years ## Time serie

#Setting the dif equation to compute incremental increase of RS

RS <- function(t,y,p){
  I <- y
  with (as.list(p),{          ### serves at using the individual names of the parameters and not p[1], p[2] etc...
    dIdt <- 0+IRS/(4*I)
    return (list(dIdt))})}

RS1 <- as.data.frame(ode(y=y0, times, RS, p))  ##report of the ode function

RS1 <- RS1 %>%
  rename(A = "1") 

RS1$A[RS1$A > MaxRS] <- MaxRS

plot(RS1)

## Differential equation to compute the increase of R:S SD ratio 
## Initial Condition  [tonnes/ha/year]
RSSD0 <- 0.0195
MaxRSSD <- 0.0978

(MaxRSSD-RSSD0)/41  ## RS is max for old forest (stqrting at 40 yrs) 

p <- (IRSSD=((MaxRSSD-RSSD0)/41)) ##Setting up the parameter (constant) 
y0 <- (I=RSSD0)  ##Setting up the initial condition
times <- years ## Time serie

#Setting the dif equation to compute incremental increase of RSSD

RSSD <- function(t,y,p){
  I <- y
  with (as.list(p),{          ### serves at using the individual names of the parameters and not p[1], p[2] etc...
    dIdt <- 0+IRSSD/(35*I)
    return (list(dIdt))})}

RSSD1 <- as.data.frame(ode(y=y0, times, RSSD, p))  ##report of the ode function

RSSD1 <- RSSD1 %>%
  rename(A = "1") 

RSSD1$A[RSSD1$A > MaxRSSD] <- MaxRSSD

plot(RSSD1)


BGCUpd <- AGCUpdTib$AGCUpd*RS1$A
BGCUpdSD <- sqrt(AGCUpdTib$AGCUpdSD^2 + RSSD1$A^2)


BGCUpdTib <- as.tibble(cbind(years, BGCUpd,BGCUpdSD))

ggplot(BGCUpdTib, aes(x=years, y= BGCUpd ))+
  geom_line()+
  geom_ribbon(aes(ymin=BGCUpd-BGCUpdSD,ymax=BGCUpd+BGCUpdSD), alpha=0.25, linetype=2)+
  ylab(bquote('Below Ground Carbon ('*' tonnes C'~ ha^-1*')'))+
  xlab("Years after transplant")+
  theme_bw()



### COMBINE SOIL C, AGC, BGC ----
TOTC <- as.tibble(cbind (Ct1$time,Ct1$DPM,Ct1$RPM,Ct1$BIO,Ct1$HUM,Ct1$IOM,AGCUpdTib$AGCUpd
                         ,AGCUpdTib$AGCUpd-AGCUpdTib$AGCUpdSD,AGCUpdTib$AGCUpd+AGCUpdTib$AGCUpdSD,BGCUpdTib$BGCUpd,BGCUpdTib$BGCUpd-BGCUpdTib$BGCUpdSD,BGCUpdTib$BGCUpd+BGCUpdTib$BGCUpdSD))
colnames(TOTC) <- c("years","DPM","RPM","BIO","HUM","IOM", "AGCMean","AGCMin","AGCMax"
                    , "BGCMean","BGCMin","BGCMax")
TOTC$TOTALCSoil <- Ct1$DPM+Ct1$RPM+Ct1$BIO+Ct1$HUM+Ct1$IOM
TOTC$TOTALCMean <- Ct1$DPM+Ct1$RPM+Ct1$BIO+Ct1$HUM+Ct1$IOM+AGCUpdTib$AGCUpd+BGCUpdTib$BGCUpd
TOTC$TOTALCMin <- Ct1$DPM+Ct1$RPM+Ct1$BIO+Ct1$HUM+Ct1$IOM+(AGCUpdTib$AGCUpd-AGCUpdTib$AGCUpdSD)+(BGCUpdTib$BGCUpd-BGCUpdTib$BGCUpdSD)
TOTC$TOTALCMax <- Ct1$DPM+Ct1$RPM+Ct1$BIO+Ct1$HUM+Ct1$IOM+(AGCUpdTib$AGCUpd+AGCUpdTib$AGCUpdSD)+(BGCUpdTib$BGCUpd+BGCUpdTib$BGCUpdSD)

TOTClong <- gather(TOTC, Cpool,Values,DPM:TOTALCMax)

ggplot(TOTClong, aes())+
  geom_line(data= subset(TOTClong, Cpool%in% c("AGCMean","BGCMean","TOTALCMean")), aes(years,Values,color=Cpool))+
  geom_line(data= subset(TOTClong, Cpool%in% c("TOTALCSoil")), aes(years,Values,color=Cpool))+
  geom_ribbon(data=TOTC,aes(x=years,ymin=TOTALCMin,ymax=TOTALCMax), alpha=0.3, linetype=2, fill="cyan")+
  # geom_crossbar(aes(x=40, y=61.35 ,ymin=59.82, ymax=62.88), width = 1, colour="red")+
  # geom_crossbar(aes(x=60, y=75.11 ,ymin=73.5, ymax=76.71), width = 1, colour="red")+
  # geom_crossbar(aes(x=90, y=96.25 ,ymin=85.6, ymax=106.91), width = 1, colour="red")+
  # geom_crossbar(aes(x=120, y=96.86 ,ymin=87.86, ymax=106), width = 1, colour="red")+
  # geom_crossbar(aes(x=40, y=12.48 ,ymin=11.50, ymax=13.46), width = 1, colour="darkgreen")+
  # geom_crossbar(aes(x=60, y=14.75 ,ymin=13.86, ymax=15.64), width = 1, colour="darkgreen")+
  # geom_crossbar(aes(x=90, y=17.45 ,ymin=17.23, ymax=17.66), width = 1, colour="darkgreen")+
  # geom_crossbar(aes(x=120, y=18.96 ,ymin=13.06, ymax=24.86), width = 1, colour="darkgreen")+
  # geom_crossbar(aes(x=40, y=62.19+47.7 ,ymin=56.2+41.1, ymax=68.1+43.3), width = 1, colour="purple")+
  # geom_crossbar(aes(x=60, y=73.11+50.2 ,ymin=63.8+39.5, ymax=82.4+61), width = 1, colour="purple")+
  # geom_crossbar(aes(x=90, y=46+32 ,ymin=41.3+24.1, ymax=50.7+39.9), width = 1, colour="purple")+
  # geom_crossbar(aes(x=120, y=54+36.7 ,ymin=48.5+32.2, ymax=59.6+41.1), width = 1, colour="purple")+
  # geom_crossbar(aes(x=40, y=62.19+47.7+61.35+12.48 ,ymin=56.2+41.1+59.82+11.50, ymax=68.1+43.3+62.88+13.46), width = 1, colour="cyan")+
  # geom_crossbar(aes(x=60, y=73.11+50.2+ 75.11+14.75,ymin=63.8+39.5+73.5+13.86, ymax=82.4+61+76.71+15.64), width = 1, colour="cyan")+
  # geom_crossbar(aes(x=90, y=46+32+96.25+17.45,ymin=41.3+24.1+85.6+17.23, ymax=50.7+39.9+106.91+17.66), width = 1, colour="cyan")+
  # geom_crossbar(aes(x=120, y=54+36.7+96.86+18.96 ,ymin=48.5+32.2+87.86+13.06, ymax=59.6+41.1+106+24.86), width = 1, colour="cyan")+### all these crossbars are to compare with "and belowground carbon stocks are decoupled in secondary tropical forests and are positively related to forest age and soil nutrients respectively (Jones et al., 2019)"
  ylab(bquote('Carbon stock ('*'tonnes C'~ ha^-1*')'))+
  xlab("Years after transplant")+
  xlim(c(0,30))+
  ylim(c(0,250))+
  theme_bw()

P2 <- ggplot(TOTClong, aes())+
  geom_line(data= subset(TOTClong, Cpool%in% c("BGCMean")), aes(years,Values-0.5,color=Cpool), size = 0.5)+
  geom_line(data= subset(TOTClong, Cpool%in% c("AGCMean")), aes(years,Values-2.5,color=Cpool), size = 0.5)+
  geom_line(data= subset(TOTClong, Cpool%in% c("TOTALCSoil")), aes(years,Values-1.3,color=Cpool))+
  ylab(bquote('Carbon stock increase ('*' tonnes C'~ ha^-1*')'))+
  xlab("")+
  annotate(geom = "label", x = 0, y =107, label ="a", color="black", size=9)+
  scale_color_discrete(name = "Carbon pool", labels = c("Above-ground vegetation", "Below-ground vegetation", "Soil"))+
  theme_bw()+
  theme(legend.position = c(0.79, 0.21),text = element_text(size=rel(4)),legend.text=element_text(size=12))

P1 <- ggplot(TOTClong, aes())+
  geom_ribbon(data=TOTC,aes(x=years,ymin=TOTALCMin,ymax=TOTALCMax), alpha=0.9, linetype=2, fill="lightgrey")+
  geom_line(data= subset(TOTClong, Cpool%in% c("TOTALCMean")), aes(years,Values), color = "black")+
  ylab(bquote('Total carbon stock increase ('*' tonnes C'~ ha^-1*')'))+
  xlab("Years after transplant")+
  annotate(geom = "label", x = 0, y =230, label ="b", color="black", size=9)+
  theme_bw()+
  theme(text = element_text(size=rel(4)),legend.text=element_text(size=12))


P2/P1

ggplot(TOTClong, aes())+
  geom_line(data= subset(TOTClong, Cpool%in% c("BGCMean")), aes(years,Values,color=Cpool), size = 0.5)+
  geom_line(data= subset(TOTClong, Cpool%in% c("AGCMean")), aes(years,Values,color=Cpool), size = 0.5)+
  geom_line(data= subset(TOTClong, Cpool%in% c("TOTALCSoil")), aes(years,Values,color=Cpool))+
  ylab("")+
  xlab("")+
  scale_color_discrete(name = "Carbon pool", labels = c("Above-ground vegetation", "Below-ground vegetation", "Soil"))+
  theme_minimal()+
  theme(axis.text.x = element_text( hjust = 1, size = 12))+  
  theme(legend.position="none", axis.text=element_text(size=10),axis.title=element_text(size=13))+
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())+
  coord_cartesian(xlim=c(0,25), ylim = c(0,60))



# ###############################################################################
##Ecosia Claim <-	https://blog.ecosia.org/100-million/ (09/07/2020) "100 million trees tackle the climate crisis by removing 1771 tonnes of CO2 every day."
#Number of tree in a forest (start at 1100 --> Ends at 565 in old growth 80 years (ter Steege et al., 2013))
TreeIni <- SeedNumb*1000
MaxTree <- 565
(MaxTree-TreeIni)/80  ##
p <- (ITree=(MaxTree-TreeIni)/80)
y0 <- (I=TreeIni)  ##Setting up the initial condition
times <- years ## Time serie
#Setting the dif equation to conpute incremental decrease of number of tree
TreeNumber <- function(t,y,p){
  I <- y
  with (as.list(p),{          ### serves at using the individual names of the parameters and not p[1], p[2] etc...
    dIdt <- ITree
    return (list(dIdt))})}
Tree1 <- as.data.frame(ode(y=y0, times, TreeNumber, p))
plot(Tree1)
Tree1 <- Tree1 %>%
  rename(A = "1")
Tree1$A[Tree1$A < MaxTree] <- MaxTree


plot(Tree1)


#### Random Refor Proj --> 100 kg per tree   ----

Eco2 <- (100/1000/3.666)*(SeedNumb*1000)

#### Reforest'action  - 150 kg CO2 per tree ## No info on seedling density
ReforAct <- 150/1000/3.666*SeedNumb*1000

#### Tree Nation -  On average we consider a tree to offset 200 kilograms of CO2 over its lifetime ## No info on seedling density
TreeNation <- 200/1000/3.666*SeedNumb*1000

####COMBINATION LCA ROTHC----
TOTClong 
TOTDFLongC <- TOTDFLong
TOTDFLongC$value <- TOTDFLong$value/3.666/1000 # put in t CARBON
TOTDFLongC$SD <- TOTDFLong$SD/3.666/1000 # put in t CARBON

#### TOTAL C 
TOTClongTOT <- filter(TOTClong,Cpool=="TOTALCMean")
TOTClongTOT$Values <- TOTClongTOT$Values+ as.numeric(TOTDFLongC[7,2])-as.numeric(TOTClongTOT[1,3])
TOTClongTOT$SD <-TOTC$TOTALCMean-TOTC$TOTALCMin
TOTClongTOT$ValuesMin<- TOTClongTOT$Values- sqrt(as.numeric(TOTDFLongC[7,3])^2+as.numeric(TOTClongTOT$SD)^2)
TOTClongTOT$ValuesMax<- TOTClongTOT$Values+ sqrt(as.numeric(TOTDFLongC[7,3])^2+as.numeric(TOTClongTOT$SD)^2)
TOTClongTOT$years <- TOTClongTOT$years-as.numeric(TOTClongTOT[1,1]) 

f1 <- approxfun(TOTClongTOT$Values, TOTClongTOT$years)
Intersect1 <-f1(0)
Intersect2 <-f1(Eco2)
Intersect21 <-f1(ReforAct)
Intersect22 <-f1(TreeNation)


# f2 <- approxfun(Eco1$Hect, Eco1$time)
# Intersect3 <-f2(Eco2)

## Without ECOSIA
ggplot(TOTClongTOT, aes())+
  geom_line(data= TOTClongTOT, aes(years,Values))+
  geom_ribbon(data= TOTClongTOT, aes(x=years,ymin=ValuesMin, ymax=ValuesMax),fill = "grey70", alpha=0.3)+
  annotate("segment", x = Intersect1, xend = Intersect1 , y = 55, yend = 0, colour = "red", size=0.2, alpha=0.6, arrow=arrow(length = unit(0.03, "npc"),type="closed"))+
  annotate(geom = "label", x = Intersect1, y =55, label =round(Intersect1, digits =2), color="red", size=3)+
  ylab(bquote('Carbon Total ('*'tonnes C'~ ha^-1*')'))+
  xlab("Years after transplant")+
  theme_bw()

## WIth Ecosia
ggplot(TOTClongTOT, aes())+
  geom_ribbon(data= TOTClongTOT, aes(x=years,ymin=ValuesMin, ymax=ValuesMax),fill = "lightgrey", alpha=0.9)+
  geom_line(data= TOTClongTOT, aes(years,Values))+
  # geom_line(data= Eco1, aes(time,Hect), colour="darkgreen")+
  annotate("segment", x = Intersect1, xend = Intersect1 , y = 25, yend = 0, colour = "red", size=0.2, alpha=0.6, arrow=arrow(length = unit(0.01, "npc"),type="closed"))+
  annotate(geom = "label", x = Intersect1, y =25, label =round(Intersect1, digits =2), color="red", size=4)+
  annotate("segment", x = Intersect2, xend = Intersect2 , y = Eco2+40, yend = Eco2, colour = "black", size=0.2, alpha=0.6, arrow=arrow(length = unit(0.01, "npc"),type="closed"))+
  annotate(geom = "label", x = Intersect2, y =Eco2+40, label =round(Intersect2, digits =1), color="black", size=4)+
  ylab(bquote('Carbon Total ('*'tonnes C'~ ha^-1*')'))+
  xlab("Years after transplant")+
  # annotate(geom = "label", x = 9, y =10, label ="Ecosia\nC increase rate", color="darkgreen", size=4)+
  annotate(geom = "label", x = 17, y =10, label ="Model\nC increase rate", color="black", size=4)+
  xlim(c(0,20))+
  ylim(c(0,300))+
  theme_bw()+
  theme(text = element_text(size=rel(4)))

#With Ecosia and a Fertile Soil simulation and only AGC

TOTClongTOT$ValuesMinSoil <- TOTClongTOT$Values - TOTC$TOTALCSoil


f2 <- approxfun(TOTClongTOT$ValuesMinSoil, TOTClongTOT$years)
Intersect4 <-f2(Eco2)

TOTClongSoil <- filter(TOTClong,Cpool=="TOTALCSoil")
TOTClongSoil$Values <- TOTClongSoil$Values+ as.numeric(TOTDFLongC[7,2])-as.numeric(TOTClongSoil[1,3])
TOTClongSoil$ValuesMin<- TOTClongSoil$Values- as.numeric(TOTDFLongC[7,3])
TOTClongSoil$ValuesMax<- TOTClongSoil$Values+ as.numeric(TOTDFLongC[7,3])
TOTClongSoil$years <- TOTClongSoil$years-as.numeric(TOTClongSoil[1,1]) 

TOTClongAGC <- filter(TOTClong,Cpool=="AGCMean")
AGCValuesMin <- filter(TOTClong,Cpool=="AGCMin")
AGCValuesMax <- filter(TOTClong,Cpool=="AGCMax")
TOTClongAGC$Values <- TOTClongAGC$Values-as.numeric(TOTClongAGC[1,3])+ as.numeric(TOTDFLongC[7,2])
TOTClongAGC$ValuesMin<- AGCValuesMin$Values - as.numeric(TOTDFLongC[7,3])-3.31+ as.numeric(TOTDFLongC[7,2])
TOTClongAGC$ValuesMax<- AGCValuesMax$Values + as.numeric(TOTDFLongC[7,3])-3.31+ as.numeric(TOTDFLongC[7,2])
TOTClongAGC$years <- TOTClongAGC$years-as.numeric(TOTClongSoil[1,1]) 


f4 <- approxfun(TOTClongAGC$Values, TOTClongAGC$years)
Intersect7 <-f4(0)
Intersect8 <-f4(Eco2)
# 
# f5 <- approxfun(Eco1$Hect, Eco1$time)
# Intersect9 <-f5(Eco2)


ggplot(TOTClongTOT, aes())+
  geom_ribbon(data= TOTClongTOT, aes(x=years,ymin=ValuesMin, ymax=ValuesMax),fill = "lightgrey", alpha=0.9)+
  geom_line(data= TOTClongTOT, aes(years,Values))+
  geom_line(data= TOTClongTOT, aes(years,ValuesMinSoil), color="orange3")+
  geom_line(data= TOTClongAGC, aes(years,Values), colour="dodgerblue2")+
  annotate("segment", x = Intersect1, xend = Intersect1 , y = 25, yend = 0, colour = "red", size=0.2, alpha=0.6, arrow=arrow(length = unit(0.01, "npc"),type="closed"))+
  annotate(geom = "label", x = Intersect1, y =25, label =round(Intersect1, digits =2), color="red", size=4)+
  annotate("segment", x = Intersect2, xend = Intersect2 , y = Eco2+32, yend = Eco2, colour = "black", size=0.2, alpha=0.6, arrow=arrow(length = unit(0.01, "npc"),type="closed"))+
  annotate(geom = "label", x = Intersect2, y =Eco2+32, label =round(Intersect2, digits =1), color="black", size=4)+
  annotate("segment", x = Intersect4, xend = Intersect4 , y = Eco2+32, yend = Eco2, colour = "orange3", size=0.2, alpha=0.6, arrow=arrow(length = unit(0.01, "npc"),type="closed"))+
  annotate(geom = "label", x = Intersect4, y =Eco2+32, label =round(Intersect4, digits =1), color="orange3", size=4)+
  annotate("segment", x = Intersect8, xend = Intersect8 , y = Eco2+32, yend = Eco2, colour = "dodgerblue2", size=0.2, alpha=0.6, arrow=arrow(length = unit(0.01, "npc"),type="closed"))+
  annotate(geom = "label", x = Intersect8, y = Eco2+32, label =round(Intersect8, digits =1), color="dodgerblue2", size=4)+
  ylab(bquote('Carbon Total ('*' tonnes C'~ ha^-1*')'))+
  xlab("Years after transplant")+
  # annotate(geom = "label", x = 4.7, y =10, label ="Ecosia\nC increase rate", color="darkgreen", size=4)+
  annotate(geom = "label", x = 9.5, y =10, label ="Model\nC All Pools", color="black", size=4)+
  annotate(geom = "label", x = 14.5, y =10, label ="Model\nC AGC + BGC", color="orange3", size=4)+
  annotate(geom = "label", x = 18, y =10, label ="Model\nC AGC", color="dodgerblue2", size=4)+
  xlim(c(-1,20))+
  ylim(c(-1,125))+
  theme_bw()+
  theme(text = element_text(size=rel(4)))


#### SOIL C 


f2 <- approxfun(TOTClongSoil$Values, TOTClongSoil$years)
Intersect4 <-f2(0)
Intersect5 <-f2(Eco2)

f3 <- approxfun(Eco1$Hect, Eco1$time)
Intersect6 <-f3(Eco2)

ggplot(TOTClongSoil, aes())+
  geom_line(data= TOTClongSoil, aes(years,Values))+
  geom_ribbon(data= TOTClongSoil, aes(x=years,ymin=ValuesMin, ymax=ValuesMax),fill = "grey70", alpha=0.3)+
  geom_line(data= Eco1, aes(time,Hect), colour="green")+
  annotate("segment", x = Intersect4, xend = Intersect4 , y = 10, yend = 0, colour = "red", size=0.2, alpha=0.6, arrow=arrow(length = unit(0.03, "npc"),type="closed"))+
  annotate(geom = "label", x = Intersect4, y =10, label =round(Intersect4, digits =2), color="red", size=3)+
  annotate("segment", x = Intersect5, xend = Intersect5 , y = Eco2+15, yend = Eco2, colour = "darkgreen", size=0.2, alpha=0.6, arrow=arrow(length = unit(0.03, "npc"),type="closed"))+
  annotate(geom = "label", x = Intersect5, y =Eco2+15, label =round(Intersect5, digits =2), color="darkgreen", size=3)+
  annotate("segment", x = Intersect6, xend = Intersect6 , y = Eco2+15, yend = Eco2, colour = "green", size=0.2, alpha=0.6, arrow=arrow(length = unit(0.03, "npc"),type="closed"))+
  annotate(geom = "label", x = Intersect6, y =Eco2+15, label =round(Intersect6, digits =2), color="green", size=3)+
  ylab(bquote('Carbon in Soil ('*'tonnes C'~ ha^-1*')'))+
  xlab("Years after transplant")+
  theme_bw()


#####AGC 



f4 <- approxfun(TOTClongAGC$Values, TOTClongAGC$years)
Intersect7 <-f4(0)
Intersect8 <-f4(Eco2)

f5 <- approxfun(Eco1$Hect, Eco1$time)
Intersect9 <-f5(Eco2)

ggplot(TOTClongAGC, aes())+
  geom_line(data= TOTClongAGC, aes(years,Values))+
  geom_ribbon(data= TOTClongAGC,aes(x=years,ymin=ValuesMin,ymax=ValuesMax),fill = "grey70", alpha=0.3)+
  geom_line(data= Eco1, aes(time,Hect), colour="green")+
  annotate("segment", x = Intersect7, xend = Intersect7 , y = 55, yend = 0, colour = "red", size=0.2, alpha=0.6, arrow=arrow(length = unit(0.03, "npc"),type="closed"))+
  annotate(geom = "label", x = Intersect7, y =55, label =round(Intersect7, digits =2), color="red", size=3)+
  annotate("segment", x = Intersect8, xend = Intersect8 , y = Eco2+55, yend = Eco2, colour = "darkgreen", size=0.2, alpha=0.6, arrow=arrow(length = unit(0.03, "npc"),type="closed"))+
  annotate(geom = "label", x = Intersect8, y = Eco2+55, label =round(Intersect8, digits =2), color="darkgreen", size=3)+
  annotate("segment", x = Intersect9, xend = Intersect9 , y = Eco2+55, yend = Eco2, colour = "green", size=0.2, alpha=0.6, arrow=arrow(length = unit(0.03, "npc"),type="closed"))+
  annotate(geom = "label", x = Intersect9, y = Eco2+55, label =round(Intersect9, digits =2), color="green", size=3)+
  ylab(bquote('Carbon in Above-ground ('*'tonnes C'~ ha^-1*')'))+
  xlab("Years after transplant")+
  theme_bw()





#Attempt to graph CO2 capture rate per tree 
tCO2Capture <- TOTClongTOT$Values*3.667
yearsCO2 <- TOTClongTOT$years
Tree1
Tree1$tCO2Capture <- tCO2Capture
Tree1$tCO2PerTree <- tCO2Capture/Tree1$A

plot(tCO2Capture)
Tree1$real <- tCO2Capture/Tree1[1,2]
Tree1$ABGCperTree <- TOTClongAGC$Values*3.667/Tree1$A
 

ggplot(Tree1, aes(x=time, y=tCO2PerTree))+
  # geom_line(color="blue")+
  # geom_line(aes(x=time,y=A), color="darkgreen")+
  geom_line(aes(x=time,y=real*1000), color="red")+
  
  # annotate(geom = "label", x = 80, y = 3500, label =expression(tonne ~CO[2]~tree^-1), color="blue", size=4)+
  annotate(geom = "label", x = 13, y = 90, label =expression(kg ~CO[2]~tree^-1~planted), color="red", size=4)+
  # geom_line(aes(x=time,y=ABGCperTree*1000), color="green")+
  # annotate(geom = "label", x = 80, y = 4000, label =expression("number of tree" ~ha^-1), color="darkgreen", size=4)+
  geom_line(aes(x=time,y=tCO2Capture))+
  annotate(geom = "label", x = 10, y = 200, label =expression("total stock increase in tonne" ~CO[2]~ha^-1), color="black", size=4)+
  annotate(geom = "segment" , x=3, xend = 3, y=0, yend = 300, colour="orange3")+
  annotate(geom = "label", x = 3, y = 300, label =expression("year 3"), color="orange3", size=4)+
  scale_y_continuous(name = expression(kg ~CO[2]~tree^-1), sec.axis = sec_axis(~.*1, name=expression(tonne ~CO[2] ~ha^-1)), limits = c(-10,350) )+
  xlab("Years after transplant")+
  xlim(c(0,20))+
  theme_bw()+
  theme(axis.title=element_text(size=12))


mean(Tree1$tCO2PerTree)


Tree1Ecosia <- Tree1[0:36,]

ggplot(Tree1Ecosia, aes(x=time, y=tCO2PerTree))+
  geom_line(color="blue")+
  geom_line(aes(x=time,y=A/1000), color="darkgreen")+
  geom_line(aes(x=time,y=real), color="yellow")+
  geom_line(aes(x=time,y=tCO2Capture/1000))+
  scale_y_continuous(
    
    # Features of the first axis
    name = "First Axis",
    
    # Add a second axis and specify its features
    sec.axis = sec_axis(~.*1000, name="Second Axis")
  )

max(Tree1Ecosia$real)*1000
mean(Tree1Ecosia$real)*1000 ##Hence, as ECOSIA state they will look after the plantation for 3 years, the carbon capture value of each of the tree planted should be advertised as 12 kg not 50. This number rises as the plantation grows.  
